@@ -44,13 +44,23 @@ SKAT(Z[IDX,], obj.s, kernel = "linear.weighted")$p.value
 
 
 ###################################################
-### code chunk number 5: SKAT3
+### code chunk number 5: SKAT22
+###################################################
+
+# default hybrid approach 
+out<-SKATBinary(Z[IDX,], obj.s, kernel = "linear.weighted")
+out$p.value
+
+
+
+###################################################
+### code chunk number 6: SKAT3
 ###################################################
 SKAT(Z, obj, kernel = "linear.weighted", weights.beta=c(0.5,0.5))$p.value
 
 
 ###################################################
-### code chunk number 6: SKAT4
+### code chunk number 7: SKAT4
 ###################################################
 # Shape of the logistic weight
 
@@ -67,19 +77,20 @@ SKAT(Z, obj, kernel = "linear.weighted", weights=weights)$p.value
 
 
 ###################################################
-### code chunk number 7: SKAT41
+### code chunk number 8: SKAT41
 ###################################################
-# Shape of the logistic weight
-
 #rho=0
 SKAT(Z, obj, r.corr=0)$p.value
 
 #rho=0.9
 SKAT(Z, obj, r.corr=0.9)$p.value
 
+#rho=1, burden test
+SKAT(Z, obj, r.corr=1)$p.value
+
 
 ###################################################
-### code chunk number 8: SKAT42
+### code chunk number 9: SKAT42
 ###################################################
 
 #Optimal Test
@@ -88,7 +99,7 @@ SKAT(Z, obj, method="optimal.adj")$p.value
 
 
 ###################################################
-### code chunk number 9: SKAT43
+### code chunk number 10: SKAT43
 ###################################################
 # Combined sum test (SKAT-C and Burden-C)
 
@@ -103,7 +114,7 @@ SKAT_CommonRare(Z, obj, r.corr.rare=1, r.corr.common=1, method="A" )$p.value
 
 
 ###################################################
-### code chunk number 10: SKAT5
+### code chunk number 11: SKAT5
 ###################################################
 # Assign missing 
 Z1<-Z
@@ -117,7 +128,7 @@ SKAT(Z1,obj,impute.method = "fixed")$p.value
 
 
 ###################################################
-### code chunk number 11: SKAT6
+### code chunk number 12: SKAT6
 ###################################################
 # parametric boostrap.
 obj<-SKAT_Null_Model(y.b ~ X, out_type="D", n.Resampling=5000, 
@@ -130,7 +141,7 @@ Get_Resampling_Pvalue(re)	# get resampling p-value
 
 
 ###################################################
-### code chunk number 12: SKAT_B1
+### code chunk number 13: SKAT_B1
 ###################################################
 # To run this code, first download and unzip example files
 
@@ -151,7 +162,7 @@ Generate_SSD_SetID(File.Bed, File.Bim, File.Fam, File.SetID, File.SSD, File.Info
 
 
 ###################################################
-### code chunk number 13: SKAT_B2
+### code chunk number 14: SKAT_B2
 ###################################################
 FAM<-Read_Plink_FAM(File.Fam, Is.binary=FALSE)
 y<-FAM$Phenotype
@@ -172,7 +183,7 @@ out
 
 
 ###################################################
-### code chunk number 14: SKAT_B2Cov
+### code chunk number 15: SKAT_B2Cov
 ###################################################
 File.Cov<-"./Example1.Cov"
 FAM_Cov<-Read_Plink_FAM_Cov(File.Fam, File.Cov, Is.binary=FALSE)
@@ -191,7 +202,7 @@ out
 
 
 ###################################################
-### code chunk number 15: SKAT_B2Weight
+### code chunk number 16: SKAT_B2Weight
 ###################################################
 
 # Custom weight
@@ -203,7 +214,7 @@ out
 
 
 ###################################################
-### code chunk number 16: SKAT_B2Save
+### code chunk number 17: SKAT_B2Save
 ###################################################
 
 output.df = out$results
@@ -212,7 +223,7 @@ write.table(output.df, file="./save.txt", col.names=TRUE, row.names=FALSE)
 
 
 ###################################################
-### code chunk number 17: SKAT_B3
+### code chunk number 18: SKAT_B3
 ###################################################
 obj<-SKAT_Null_Model(y ~ 1, out_type="C", n.Resampling=1000, type.Resampling="bootstrap")
 out<-SKAT.SSD.All(SSD.INFO, obj)
@@ -225,7 +236,7 @@ Resampling_FWER(out,FWER=0.5)
 
 
 ###################################################
-### code chunk number 18: SKAT_B4
+### code chunk number 19: SKAT_B4
 ###################################################
 
 obj<-SKAT_Null_Model(y ~ 1, out_type="C")
@@ -245,7 +256,7 @@ SKAT(Z, obj, weights=weights)$p.value
 
 
 ###################################################
-### code chunk number 19: SKAT_B5
+### code chunk number 20: SKAT_B5
 ###################################################
 
 # test all genes in SSD file
@@ -257,13 +268,63 @@ out
 
 
 ###################################################
-### code chunk number 20: SKAT_B5
+### code chunk number 21: SKAT_B5
 ###################################################
 Close_SSD()
 
 
 ###################################################
-### code chunk number 21: data
+### code chunk number 22: SKAT_BB1
+###################################################
+
+# File names
+File.Bed<-"./SKATBinary.example.bed"
+File.Bim<-"./SKATBinary.example.bim"
+File.Fam<-"./SKATBinary.example.fam"
+File.Cov<-"./SKATBinary.example.cov"
+File.SetID<-"./SKATBinary.example.SetID"
+File.SSD<-"./SKATBinary.example.SSD"
+File.Info<-"./SKATBinary.example.SSD.info"
+
+# Generate SSD file, and read fam and cov files
+# If you already have a SSD file, you do not need to call this function. 
+Generate_SSD_SetID(File.Bed, File.Bim, File.Fam, File.SetID, File.SSD, File.Info)
+FAM<-Read_Plink_FAM_Cov(File.Fam, File.Cov, Is.binary=TRUE, cov_header=FALSE)
+
+# open SSD files
+ 
+SSD.INFO<-Open_SSD(File.SSD, File.Info)
+
+# No adjustment is needed
+obj<-SKAT_Null_Model(Phenotype ~ COV1 + COV2, out_type="D", data=FAM, Adjustment=FALSE)
+
+
+# SKAT
+out.skat<-SKATBinary.SSD.All(SSD.INFO, obj, method="SKAT")
+
+# SKAT-O
+out.skato<-SKATBinary.SSD.All(SSD.INFO, obj, method="SKATO")
+
+# First 5 variant sets, SKAT
+out.skat$results[1:5,]
+
+
+
+###################################################
+### code chunk number 23: SKAT_BB2
+###################################################
+
+# Effective number of test is smaller than 30 (number of variant sets)
+# Use SKAT results
+Get_EffectiveNumberTest(out.skat$results$MAP, alpha=0.05)
+
+# QQ plot
+QQPlot_Adj(out.skat$results$P.value, out.skat$results$MAP)
+
+
+
+###################################################
+### code chunk number 24: data
 ###################################################
 data(SKAT.haplotypes)
 names(SKAT.haplotypes)
@@ -272,7 +333,7 @@ attach(SKAT.haplotypes)
 
 
 ###################################################
-### code chunk number 22: SKAT_P1
+### code chunk number 25: SKAT_P1
 ###################################################
 set.seed(500)
 out.c<-Power_Continuous(Haplotype,SNPInfo$CHROM_POS, SubRegion.Length=5000,    
@@ -289,7 +350,7 @@ Get_RequiredSampleSize(out.b, Power=0.8)
 
 
 ###################################################
-### code chunk number 23: SKAT_P2
+### code chunk number 26: SKAT_P2
 ###################################################
 set.seed(500)
 out.c<-Power_Continuous_R(Haplotype,SNPInfo$CHROM_POS, SubRegion.Length=5000,    
